Data Transformation
*******************

Discretization
=================================================

.. automodule:: nzpyida.analytics.transform.discretization
   :members:
   :undoc-members:
   :show-inheritance:

Data Preparation
=================================================

.. automodule:: nzpyida.analytics.transform.preparation
   :members:
   :undoc-members:
   :show-inheritance:

